pub struct TakCotMessage {
pub cot_type: TakCotType,
pub cot_msg: CotUnparsedDetail,
}Expand description
Result of parsing a TAK CoT message and attempting to detect a message type.
We don’t actually parse the <detail> section, since it is so dynamic in practice.
Thus, callers are responsible for further parsing of that section, for example using
quick_xml::Reader.
Fields
cot_type: TakCotTypecot_msg: CotUnparsedDetailAuto Trait Implementations
impl Freeze for TakCotMessage
impl RefUnwindSafe for TakCotMessage
impl Send for TakCotMessage
impl Sync for TakCotMessage
impl Unpin for TakCotMessage
impl UnwindSafe for TakCotMessage